@@ -411,7 +411,7 @@ bool SecretAgent::processGetSecrets(SecretsRequest &request) const
         }
     }
 
-    if (!Configuration::showPasswordDialog()) {
+    if (!Configuration::self().showPasswordDialog()) {
         sendError(SecretAgent::NoSecrets, "Cannot authenticate", request.message);
         emit secretsError(request.connection_path.path(), i18n("Authentication to %1 failed. Wrong password?", request.connection.value("connection").value("id").toString()));
         return true;
